@@ -1,8 +1,8 @@
-/* $Id: miniupnpcmodule.c,v 1.30 2017/04/21 10:07:43 nanard Exp $*/
+/* $Id: miniupnpcmodule.c,v 1.32 2018/05/03 08:17:48 nanard Exp $*/
 /* Project : miniupnp
  * Author : Thomas BERNARD
- * website : http://miniupnp.tuxfamily.org/
- * copyright (c) 2007-2016 Thomas Bernard
+ * website : https://miniupnp.tuxfamily.org/
+ * copyright (c) 2007-2018 Thomas Bernard
  * This software is subjet to the conditions detailed in the
  * provided LICENCE file. */
 #include <Python.h>
@@ -307,7 +307,7 @@ UPnP_addportmapping(UPnPObject *self, PyObject *args)
 	const char * remoteHost;
 	const char * leaseDuration = "0";
 	int r;
-	if (!PyArg_ParseTuple(args, "HssHss", &ePort, &proto,
+	if (!PyArg_ParseTuple(args, "HssHzz", &ePort, &proto,
 	                                     &host, &iPort, &desc, &remoteHost))
         return NULL;
 Py_BEGIN_ALLOW_THREADS
@@ -349,7 +349,7 @@ UPnP_addanyportmapping(UPnPObject *self, PyObject *args)
 	const char * remoteHost;
 	const char * leaseDuration = "0";
 	int r;
-	if (!PyArg_ParseTuple(args, "HssHss", &ePort, &proto, &host, &iPort, &desc, &remoteHost))
+	if (!PyArg_ParseTuple(args, "HssHzz", &ePort, &proto, &host, &iPort, &desc, &remoteHost))
         return NULL;
 Py_BEGIN_ALLOW_THREADS
 	sprintf(extPort, "%hu", ePort);
@@ -405,14 +405,14 @@ UPnP_deleteportmappingrange(UPnPObject *self, PyObject *args)
 	unsigned short ePortEnd;
 	const char * proto;
 	unsigned char manage;
-	char manageStr[1];
+	char manageStr[6];
 	int r;
 	if(!PyArg_ParseTuple(args, "HHsb", &ePortStart, &ePortEnd, &proto, &manage))
 		return NULL;
 Py_BEGIN_ALLOW_THREADS
 	sprintf(extPortStart, "%hu", ePortStart);
 	sprintf(extPortEnd, "%hu", ePortEnd);
-	sprintf(manageStr, "%hhu", manage);
+	sprintf(manageStr, "%hu", (unsigned short)manage);
 	r = UPNP_DeletePortMappingRange(self->urls.controlURL, self->data.first.servicetype,
 					extPortStart, extPortEnd, proto, manageStr);
 Py_END_ALLOW_THREADS
