@@ -1,11 +1,15 @@
 #! /usr/bin/python
-# $Id: setupmingw32.py,v 1.9 2014/05/19 22:31:52 nanard Exp $
+# vim: tabstop=8 shiftwidth=8 expandtab
+# $Id: setupmingw32.py,v 1.10 2015/10/26 17:03:17 nanard Exp $
 # the MiniUPnP Project (c) 2007-2014 Thomas Bernard
 # http://miniupnp.tuxfamily.org/ or http://miniupnp.free.fr/
 #
 # python script to build the miniupnpc module under windows (using mingw32)
 #
-from distutils.core import setup, Extension
+try:
+        from setuptools import setup, Extension
+except ImportError:
+        from distutils.core import setup, Extension
 from distutils import sysconfig
 sysconfig.get_config_vars()["OPT"] = ''
 sysconfig.get_config_vars()["CFLAGS"] = ''
